// Copyright 2014 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.devtools.build.lib.actions;

import com.google.common.collect.ImmutableList;

/**
 * An interface for creating artifacts from their serialized representations.
 *
 * @see ArtifactSerializer
 */
public interface ArtifactDeserializer {

  /**
   * Looks up an artifact by an integer id.
   *
   * <p>This is a dual of {@link ArtifactSerializer#getArtifactId}.
   */
  Artifact lookupArtifactById(int artifactId);

  /**
   * Maps a list of artifact ids to a list of artifacts.
   *
   * <p>This is a batch version of {@link #lookupArtifactById}, provided for efficiency. It takes
   * an iterable of boxed integers because that's what the proto wrapper provides.
   */
  ImmutableList<Artifact> lookupArtifactsByIds(Iterable<Integer> artifactIds);
}
