// Copyright 2014 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.google.devtools.build.lib.pkgcache;

import com.google.devtools.build.lib.concurrent.ThreadSafety;
import com.google.devtools.build.lib.packages.Target;

import java.io.Serializable;

/**
 * A filtering policy defines how target patterns are matched. For instance, we may wish to select
 * only tests or no tests.
 */
public interface FilteringPolicy extends Serializable {

  /**
   * Returns true if this target should be retained.
   *
   * @param explicit true iff the label was specified explicitly, as opposed to being discovered by
   *                 a wildcard.
   */
  @ThreadSafety.ThreadSafe
  boolean shouldRetain(Target target, boolean explicit);
}
