// Copyright 2016 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.devtools.build.lib.util;

/**
 * Interface accepting requests to put current thread to sleep.
 *
 * <p>The only implementation of this interface intended for production use is {@link JavaSleeper}.
 * Use {@link com.google.devtools.build.lib.testutil.ManualSleeper ManualSleeper} for testing.
 */
public interface Sleeper {

  /**
   * Puts current thread to sleep for given duration.
   *
   * @throws InterruptedException if current thread is being cast into oblivion
   * @throws IllegalArgumentException if {@code milliseconds} is negative
   */
  void sleepMillis(long milliseconds) throws InterruptedException;
}
