// Copyright 2014 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
package com.google.devtools.build.lib.testutil;

import com.google.devtools.build.lib.util.OS;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * An annotation class which we use to attach a little meta data to test
 * classes. For now, we use this to attach a {@link Suite}.
 */
@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface TestSpec {

  /**
   * The size of the specified test, in terms of its resource consumption and
   * execution time.
   */
  Suite size() default Suite.SMALL_TESTS;

  /**
   * The name of the suite to which this test belongs.  Useful for creating
   * test suites organised by function.
   */
  String suite() default "";

  /**
   * True, if the test will is not dependable because it has a chance to fail regardless of the
   * code's correctness. If this is the case, the test should be fixed as soon as possible.
   */
  boolean flaky() default false;

  /**
   * True, if the test cannot run in a remote execution environment and has to run on the local
   * machine.
   */
  boolean localOnly() default false;

  /**
   * An array of operating systems that the test can run under. If not specified, the test can
   * run under all operating systems.
   */
  OS[] supportedOs() default {};
}
